==> bigloo_2.7a-1.tar.gz: bigloo2.7a/bde/bmem/bmem/param.scm <==
;*=====================================================================*/
;*    serrano/prgm/project/bigloo/bde/bmem/bmem/param.scm              */
;*    -------------------------------------------------------------    */
;*    Author      :  Manuel Serrano                                    */
;*    Creation    :  Fri Apr 25 09:24:44 2003                          */
;*    Last change :  Tue Oct 18 14:13:59 2005 (serrano)                */
;*    Copyright   :  2003-05 Manuel Serrano                            */
;*    -------------------------------------------------------------    */
;*    Bmem parameters                                                  */
;*=====================================================================*/

;*---------------------------------------------------------------------*/
;*    The module                                                       */
;*---------------------------------------------------------------------*/
(module bmem_param
   (export *bmem*
	   *bmem-version*

	   *fout*
	   *file*
	   *function*
	   *type*

	   *hostname*
	   *port*
	   *uri*

	   *css-path*
	   *sizeof-word*))

;*---------------------------------------------------------------------*/
;*    Global parameters                                                */
;*---------------------------------------------------------------------*/
(define *bmem* "bmem")
(define *bmem-version* "0.1")

;*---------------------------------------------------------------------*/
;*    IOs                                                              */
;*---------------------------------------------------------------------*/
(define *fout* #f)
(define *file* #f)
(define *function* #f)
(define *type* #f)

;*---------------------------------------------------------------------*/
;*    HTTP connection                                                  */
;*---------------------------------------------------------------------*/
(define *hostname* #f)
(define *port* #f)
(define *uri* #f)

;*---------------------------------------------------------------------*/
;*    CSS path                                                         */
;*---------------------------------------------------------------------*/
(define *css-path-variables* `("HTTP_HOP_CONFIG" "HTTP_HOP_ETC"))
(define *css-path* (filter string? (map getenv *css-path-variables*)))

;*---------------------------------------------------------------------*/
;*    Word size                                                        */
;*---------------------------------------------------------------------*/
(define *sizeof-word* 4)

==> bigloo3.1a.tar.gz: bigloo3.1a/bde/bmem/bmem/param.scm <==
;*=====================================================================*/
;*    serrano/prgm/project/bigloo/bde/bmem/bmem/param.scm              */
;*    -------------------------------------------------------------    */
;*    Author      :  Manuel Serrano                                    */
;*    Creation    :  Fri Apr 25 09:24:44 2003                          */
;*    Last change :  Mon Jun 12 11:06:37 2006 (serrano)                */
;*    Copyright   :  2003-06 Manuel Serrano                            */
;*    -------------------------------------------------------------    */
;*    Bmem parameters                                                  */
;*=====================================================================*/

;*---------------------------------------------------------------------*/
;*    The module                                                       */
;*---------------------------------------------------------------------*/
(module bmem_param
   (export *bmem*
	   *bmem-version*

	   *fout*
	   *file*
	   *function*
	   *type*

	   *hostname*
	   *port*
	   *uri*

	   *css-path*
	   *sizeof-word*))

;*---------------------------------------------------------------------*/
;*    Global parameters                                                */
;*---------------------------------------------------------------------*/
(define *bmem* "bglmem")
(define *bmem-version* "0.2")

;*---------------------------------------------------------------------*/
;*    IOs                                                              */
;*---------------------------------------------------------------------*/
(define *fout* #f)
(define *file* #f)
(define *function* #f)
(define *type* #f)

;*---------------------------------------------------------------------*/
;*    HTTP connection                                                  */
;*---------------------------------------------------------------------*/
(define *hostname* #f)
(define *port* #f)
(define *uri* #f)

;*---------------------------------------------------------------------*/
;*    CSS path                                                         */
;*---------------------------------------------------------------------*/
(define *css-path-variables* `("HTTP_HOP_CONFIG" "HTTP_HOP_ETC"))
(define *css-path* (filter string? (map getenv *css-path-variables*)))

;*---------------------------------------------------------------------*/
;*    Word size                                                        */
;*---------------------------------------------------------------------*/
(define *sizeof-word* 4)
